#
# spec file for package qmmp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __provides_exclude_from ^%{_libdir}/qmmp-[0-9\.]*/
%define sover   2
%define mver    2.1
%bcond_with faad
%bcond_with restricted
Name:           qmmp
Version:        2.1.9
Release:        2.1
Summary:        Qt-based Multimedia Player
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://qmmp.ylsoftware.com/
Source:         https://qmmp.ylsoftware.com/files/%{name}/%{mver}/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE qmmp-default_pulse.patch reddwarf@opensuse.org -- Use PulseAudio instead of ALSA by default.
Patch0:         %{name}-default-pulse.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  musepack-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libmms)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libsidplayfp)
BuildRequires:  pkgconfig(libspa-0.2)
BuildRequires:  pkgconfig(libxmp)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(shout)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(wildmidi)
Requires:       %{name}(%{sover})(Input)
Requires:       %{name}(%{sover})(Output)
Requires:       %{name}(%{sover})(Ui)
ExclusiveArch:  %ix86 x86_64
%if %{with faad}
BuildRequires:  pkgconfig(faad2)
%endif

%description
This program is an audio-player, written with help of Qt library.

%package -n lib%{name}%{sover}
Summary:        Qmmp library
Group:          System/Libraries
Recommends:     lib%{name}-plugins

%description -n lib%{name}%{sover}
This program is an audio-player, written with help of Qt library.

This package provides the Qmmp library.

%package -n lib%{name}-plugins
Summary:        Plugins for libqmmp
Group:          System/Libraries
# Suggests instead of Recommends since MPlayer is too big of a dependency.
Suggests:       lib%{name}-plugin-mplayer
Provides:       %{name}(%{sover})(Input)
Provides:       %{name}(%{sover})(Output)
Provides:       %{name}(%{sover})(Ui)
# libqmmp0-plugins & qmmp-plugin-pack-simple-ui were last used in openSUSE 13.2 (in PMBS).
Provides:       %{name}-plugin-pack-simple-ui = %{version}
Obsoletes:      %{name}-plugin-pack-simple-ui < %{version}
Obsoletes:      lib%{name}0-plugins < %{version}

%description -n lib%{name}-plugins
This program is an audio-player, written with help of Qt library.

This package provides plugins for libqmmp.

%if %{with restricted}
%package -n lib%{name}-plugin-mplayer
Summary:        MPlayer plugin for libqmmp
Group:          System/Libraries
Requires:       MPlayer

%description -n lib%{name}-plugin-mplayer
This program is an audio-player, written with help of Qt library.

This package provides MPlayer plugin for libqmmp.
%endif

%package -n lib%{name}-devel
Summary:        Development files for libqmmp
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description -n lib%{name}-devel
This program is an audio-player, written with help of Qt library.

Development files for libqmmp.

%prep
%autosetup -p1

%build
%cmake_qt6 \
  -DCMAKE_MODULE_LINKER_FLAGS="" \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
  -DLIB_DIR=%{_lib}              \
  -DPLUGIN_DIR=%{_lib}/%{name}-%{mver} \
%if %{without restricted}
  -DUSE_MPLAYER=OFF              \
%endif
  -DUSE_HAL=OFF                  \
  -DUSE_OSS=OFF                  \
  -DUSE_OSS4=OFF
%qt6_build

%install
%qt6_install

# Do not install weirdly-sized icons.
rm -r %{buildroot}/%{_datadir}/icons/hicolor/56x56

%post -n lib%{name}%{sover} -p /sbin/ldconfig

%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/solid/

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}*.so.%{sover}*

%files -n lib%{name}-plugins
%{_libdir}/%{name}-%{mver}/
%if %{with restricted}
%exclude %{_libdir}/%{name}-%{mver}/Engines/libmplayer.so
%endif

%if %{with restricted}
%files -n lib%{name}-plugin-mplayer
%dir %{_libdir}/%{name}-%{mver}/
%dir %{_libdir}/%{name}-%{mver}/Engines/
%{_libdir}/%{name}-%{mver}/Engines/libmplayer.so
%endif

%files -n lib%{name}-devel
%{_includedir}/%{name}/
%{_includedir}/%{name}ui/
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}ui.pc

%changelog
* Mon Nov 11 2024 olaf@aepfle.de
- Convert BuildRequires from libfaad-devel to pkgconfig(faad2)
* Fri Oct 18 2024 ming li <mli@suse.com>
- Update to version 2.1.9
  * fixed build with PipeWire version less than 0.3.33
  * fixed displaying bitrate in the wavpack plugin
  * disabled Qt 6.7 build warnings
  * disabled waveform seekbar for CD tracks in the simple user
    interface
* Sun Jun 30 2024 jun wang <jgwang@suse.com>
- Update to version 2.1.8
  + changes from version 2.1.8
  * improved CUE parser
  * fixed pkg-config files generated by qmake
  * fixed memory leak
  * fixed issue with missing mount points in the qmmp file
    dialog
  * fixed unexpected startup of the disabled plugin when trying
    to change
    it's settings
  * fixed linking with xcb
  * fixed crash when trying to remove queued track
  * fixed copying of the selected tracks to the new playlist
  * fixed Wayland compatibility on first startup
  + changes from version 2.1.7
  * using XWayland for skinned user interface
  * using floating point output in the sndfile plugin
  * fixed file type determination by content in the sndfile
    plugin
  * fixed memory leak in the hotkey plugin
  * fixed stream sample rate in the pipewire plugin
  * fixed issue with KDE6 file dialog
  + changes from version 2.1.6
  * added TagLib 2.0 support
  * fixed settings form in the simple user interface
  * improved lyrics plugin:
  - fixed issue with URL formatting
  - updated lyrics providers
  - using UTF-8 for all lyrics providers
  * updated Spanish translation
  + remove patch qmmp-taglib2.patch because it applied in
    source code
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add qmmp-taglib2.patch: Fix build against taglib 2.0. Patch taken
  from https://sourceforge.net/p/qmmp-dev/code/11255/
* Sun Oct 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.5:
  * added waveform seekbar optimization (Linearithmik)
  * fixed visualization initialization in the simple user
    interface
  * fixed playlist geometry issues in the simple user interface
  * fixed playlist settings in the skinned user interface
  * fixed possible crash
  * fixed http version
  * fixed file type determination by content in the waveform
    seekbar
* Fri May 26 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.1.4:
  * Add projectM 4.0 support (experimental).
  * Rebuild skin cache if missing
  * Fix removing of the current playing file in the file operations
    plugin.
  * Fix crash on streams in the lyrics plugin.
  * Fix issues with tabbar in the simple ui plugin.
  * Fix issues with visualisation windows on application startup.
* Fri Mar 31 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.1.3:
  * Fix latest cURL API support.
  * Fix crash in the ladspa plugin (Linearithmik).
  * Fix memory leak in the wavpack plugin.
  * Fix ADTS header detection in the aac plugin.
  * Fix error handling in the ffmpeg plugin.
  * Fix text scroller geometry in the skinned plugin.
  * Hide empty plugin categories.
  * Update translations.
* Mon Sep 26 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.1.2:
  * Add FFmpeg 5.1 support.
  * Add recursive search for presets in the projectm plugin.
  * Add application icon in the pulseaudio plugin.
  * Improve visualisation synchronisation.
  * Fix title formatting in the KDE notification plugin.
  * Fix "fact" chunks support in the sndfile plugin.
  * Fix embedded cover art support in the flac plugin.
  * Fix tag editor behaviour.
  * Update translations.
* Fri Jun 10 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.1.1:
  * Fix skin selection setting.
  * Fix API documentation.
  * Fix udisks plugin build.
  * Fix build with Qt 6.4.
  * Fix AppStream metadata.
  * Remove hal plugin.
  * Update translations.
* Tue May 17 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.1.0:
  * Add feature to extract lyrics from tags (id3v2 tag and
    Xiph Comment).
  * Add queue display in the "jump to track" dialogue.
  * Add a feature to skip already existing tracks.
  * Add volume change notification in the KDE notification plugin.
  * Add XDG Base Directory Specification support.
  * Replace modplug plugin by xmp plugin.
  * Improve the qsui plugin:
    + add a feature to hide playlist name filter;
    + add a feature to hide menu panel.
  - Add an application menu
    + enable clear button for some search filters;
    + improve file system browser context menu.
  * improved history plugin:
    + add a feature to remove tracks from history;
    + add a feature to show track details.
  * Improved the "about..." dialogue.
  * Improve file name filter configuration in the ffmpeg plugin.
  * Increase the minimal required Qt version to 5.5.
  * Optimise search for duplicated tracks.
  * Optimise track queue.
  * Resolve conflict between the 1.x and 2.x versions.
  * Update translations.
- Drop qmmp-fix-openmpt.patch: fixed upstream.
* Wed Apr 13 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.0.4:
  * Fix drag-and-dropped tracks order.
  * Fix an issue with empty content type.
  * Disable waveform seekbar for the tracks with unknown duration.
  * Fix the taskbar plugin.
  * Update translations.
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use the Qt6 cmake macros to fix the 15.4 build.
* Sun Jan 23 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.0.3 (changes since 1.5.1):
  * Switch to Qt6.
  * Use libiconv for charset conversion.
  * Fix default settings in the ffmpeg plugin.
  * Fix transition between http tracks.
  * Improve qsui plugin:
    + fix toolbar renaming;
    + fix Wayland support;
    + fix tab bar context menu.
  * Enable QtMultimedia support under Qt 6.2 or higher.
  * Remove private API usage Qt 6.2 or higher.
  * Fix transport plugins loading.
  * Fix volume bar draw in the double size mode.
  * Fix symlinks support.
  * Fix some issues in the two-panel file dialogue.
  * Remove KDE 4 notifications support
  * Disable unsupported plugins: taskbar, qtmultimedia.
- Rebase qmmp-fix-openmpt.patch.
- Drop qmmp-fix_cdda_version.patch: no longer applicable.
- Add requirements for libarchive, libshout, Musepack, WildMIDI
  and PipeWire support.
- Switch from libmpg123 to MAD.
- Drop baselibs.conf.
* Mon Jul 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.1
  * added application startup optimization
  * added Korean translation
  * enabled Matroska container by default in the ffmpeg plugin
  * removed mp3lyrics.org lyrics provider
  * improved qsui plugin:
    + added waveform seekbar optimization
    + fixed waveform generation for 16-bit samples
  * fixed plugin cache cleanup
  * fixed build without mpg123
  * fixed ladspa plugin regression
* Mon May 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.0
  * added media library plugin (experimental)
  * added PipeWire plugin (experimental)
  * added built-in CUE editor
  * added m4b support in the ffmpeg plugin
  * added option to enable CRC checking in the mpeg plugin
  * added ID3v1/ID3v2 charset detection using librcd library in
    the mpeg plugin
  * added WebP format support for cover image
  * added groups rebuilding after playlist updating
  * added metadata formatter optimization
  * added "%%dir()" function in the metadata formatter
  * added feature to integrate widgets to the main interface
    from plugins
  * added feature to execute external command in the fileops
    plugin
  * improved visualization synchronization
  * improved lyrics plugin:
    + added widget mode
    + show text of the current playing song (in the widget mode
    only)
    + changed user interface
  * improved qsui plugin:
    + added feature to add dock widgets from plugins
    + added feature to change tab bar position
    + added icons to the file system browser menu
    + added feature to place dock widgets in the multiple lines
    + removed "Actions" submenu, using "Tools" menu instead
  * improved skinned plugin:
    + added playlist color settings
    + moved "Show playlists" option to "Playlist" submenu
    + moved "group tracks" and "show header" options to
    "Playlist" submenu
  * removed some deprecated API usage
  * removed obsolete code
  * changed minimal FFmpeg version to 3.4
  * updated Portuguese, Dutch, Polish, Galician, Spanish,
    Russian, Ukrainian, French, Indonesian, Greek, Italian,
    German and Finnish translations
- Refresh qmmp-fix-openmpt.patch
- Switch build from mad to mpg123
* Sun May  9 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.4.6
  * added application startup optimization
  * added X11 session checking in the notifier plugin
  * fixed provider settings parsing in the lyrics plugin
  * fixed equalizer form in the qsui plugin
  * fixed build with the latest ffmpeg version
  * updated Portuguese translation (Sérgio Marques)
  * updated Italian translation (Luigi Toscano)
  * updated French translation (Adrien Vigneron)
* Thu Apr 29 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.4.5
  * added TagLib 1.12 support
  * disabled CRC checking in the mpeg plugin
  * fixed playlist update
  * fixed build with gcc 11
  * fixed API documentation
  * fixed skin search path
  * fixed application icons
* Fri Feb  5 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.4.4
  * fixed crash when changing audio parameters
  * fixed memory leak
  * removed lyrics.wikia.com provider (service was closed)
  * using plain text in the KDE tray tooltip
  * updated Dutch translation
  * updated Galician translation
  * updated Spanish translation
  * updated Bulgarian translation
* Fri Dec 18 2020 aloisio@gmx.com
- Update to version 1.4.3
  * fixed possible crash on general plugin restart
  * fixed dithering
  * fixed memory leak
  * fixed ignored files checking
  * fixed cue tracks support in the converter plugin
  * fixed issue with missing disc number in the mpeg plugin
  * fixed possible freezing on playback resume
  * updated Finnish translation
  * updated Bulgarian translation
* Sun Sep 20 2020 aloisio@gmx.com
- Update to version 1.4.2
  * fixed playlist updating
  * fixed memory leak
  * fixed kwin support
  * fixed xing header parsing in the mpeg plugin
  * updated Greek translation (Dimitrios Glentadakis)
* Fri Jul 17 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.4.1:
  * Fix "jump to track" dialogue delay.
  * Fix the feature to disable formats in the ffmpeg plugin.
  * Fix some streams detection in the mpeg plugin.
  * Fix a loss of equaliser settings.
  * Fix codec and bitrate display for IceCast streams.
  * Fix playback start-up detection in the mpris plugin.
  * Update translations.
* Thu Apr 30 2020 aloisio@gmx.com
- Update to version 1.4.0
  * added sleep mode inhibition plugin
  * added separate ListenBrainz submission plugin
  * added feature to auto-hide empty service menus
  * added option to disable two passes for equalizer
  * added fast mute function for most output plugins
  * added shared CUE parser
  * added feature to transit between playlists
  * added optimizations for flac plugin
  * added feature to select playlist format from the file dialog
  * added '--pl-next' and '--pl-prev' command line options
  * added SOCKS5 proxy support
  * added feature to display average bitrate
  * added average bitrate displaying for shoutcast/icecast
    streams
  * added Ogg Opus support in the ReplayGain scanner
  * added feature to merge different tag types in the mpeg plugin
  * added feature to start command on application startup/exit
  * added 'make docs' build target
  * added big endian support formats in the PulseAudio plugin
  * added feature to write singe file in the file writer plugin
  * improved qsui plugin:
    + added feature to override track background color
    + added scope visualization
    + added feature to reset visualization colors
    + added waveform seek bar
    + added alternate analyzer appearance
    + using gradients between analyzer colors
    + improved status bar
  * improved ffmpeg plugin:
    + added opus bitrate issue workaround
    + added new implementation of the read function
    + added embedded CUE sheet support (for Monkey's Audio
    format)
    + added format name displaying
    + added DSD (Direct Stream Digital) support
    + changed minimal ffmpeg version to 3.2
    + removed libav support
  * improved lyrics plugin:
    + added feature to save window geometry
    + added multiple lyrics providers support (based on Ultimare
    Lyrics plugin)
  * improved cdaudio plugin:
    + show more metadata
    + added KDE Solid integration
  * improved remote playlists support
  * improved m3u support
  * using qsui by default for Wayland sessions
  * fixed API documentation
  * updated Portuguese, Dutch, Polish, Galician, Spanish,
    Russian, Ukrainian, French, Indonesian, Greek, Italian and
    German translations
- Refreshed qmmp-fix_cdda_version.patch
* Thu Mar 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.3.7:
  * Use gnudb.org as a default CDDB server.
  * Fix several crashes in the file operations plugin.
  * Fix MPRIS support.
  * Fix text scroller issues in the skinned plugin.
  * Fix a CMake warning.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jan 15 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.6
  * added 'album artist' and 'composer' tags support in the
    ffmpeg plugin
  * fixed window title updating when playing CUE tracks
  * fixed crash on Futura skin in the skinned ui
  * updated French translation (Adrien Vigneron)
  * updated Indonesian translation (Andika Triwidada and Wantoyo)
  version 1.3.5:
  * added icon for 'play/pause' action
  * fixed 'album artist' tag support
  * fixed issue with missing bitrate after application restart
  * fixed issue with incorrect audio properties displaying
  * fixed crash on corrupted .m4a files
  * fixed duration overflow
  * fixed playlist duration update
  * fixed issue with special symbols in the track change plugin
  * fixed crash on encrypted archives
  * updated Galician translation (Delio Docampo Cordeiro)
* Wed Sep  4 2019 olaf@aepfle.de
- Own /usr/share/metainfo if needed
* Tue Aug 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.4
  * improved mp3 file determination
  * added format name in the ffmpeg plugin
  * fixed pausing logic
  * fixed random crash when changing audio settings
  * fixed crash in the QtMultimedia plugin
  * fixed build warning
  * fixed duration formatting
  * fixed ReplayGain support
  * fixed memory leak
  * fixed multiple channels support in the equalizer
  * updated Ukrainian translation (Gennady Motsyo)
  * updated Italian translation (Luigi Toscano)
* Sun Jun 16 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.3
  * added float output support for PulseAudio, ALSA and OSS4
  * added AppStream information (Joel Barrios Dueñas)
  * added more icon sizes
  * improved channel conversion
  * fixed feature to remove tracks when using quick search in
    the qsui plugin
  * fixed crash on some corrupted archives
  * fixed logo animation in the qsui plugin
  * fixed freezing in the ffmpeg plugin
  * updated Dutch translation (Heimen Stoffels)
  * updated Greek translation (Dimitrios Glentadakis)
* Sun May  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.2
  * added feature to play track on double click in the history
    plugin
  * using album cover from file by default
  * fixed lyrics plugin
  * fixed API documentation
  * fixed issue with read-only mode for FLAC files
  * fixed issue with missing properties for some CUE tracks
  * fixed shortcuts displaying in context menus under Qt 5.10 or
    higher
  * fixed Qt 5.13 support
  * fixed crash under Wayland session
  * fixed freezing on some corrupted files in the ffmpeg plugin
  * fixed crash on some streams in the ffmpeg plugin
  * fixed file type determination by content in the mpeg plugin
* Sat Mar  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.1
  * added projectM 3.1 support
  * added feature to determine plugin prefix via pkgconfig (Chris
    Spiegel)
  * fixed current track text color in the qsui plugin
  * fixed command line processing under Windows
  * fixed AAC support
  * fixed kwin.sh script (D1mon)
  * updated Polish translation (mrerexx)
  * updated Portuguese translation (Sérgio Marques)
  * updated Finnish translation (Jiri Grönroos)
  * updated Russian translation (Alexey Loginov)
- Dropped qmmp-projectM-qt5.patch
* Fri Mar  1 2019 olaf@aepfle.de
- Fix filelist for restricted build
* Tue Feb 19 2019 Luigi Baldoni <aloisio@gmx.com>
- Use correct path for plugin search, fixes (boo#1125787)
* Mon Feb 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.0
  * added history plugin
  * added mono to stereo converter
  * added mpg123-based decoder
  * added PulseAudio volume control
  * added cover edition feature
  * added playlist reading/writing optimization
  * added TAK support
  * added feature to send listened tracks to  ListenBrainz
  * added sorting by time in the history plugin
  * changed KDE notification plugin description
  * improved skinned plugin:
    + added KWin rules
    + added feature to hide splitters
    + added alternate splitter colors
    + added ability to hold the first visible track while
    loading a playlist
  * improved qsui plugin:
    + added feature to hide splitters
    + added feature to change splitter color
    + added ability to hold the first visible track while
    loading a playlist
  * moved removable volumes to the "add" menu
  * improved http plugin:
    + reduced number of memory allocations
    + limited maximum buffer size
  * improved stream browser:
    + added feature to edit bookmark list
    + moved launch action from "tools" to "add" menu
  * added track properties to the title formatting fields
  * added feature to disable tag reading while loading a
    playlist file
  * reduced number of locks
  * improved command line support
  * fixed "--pl-help", "--nowplaying-syntax" command line
    options processing
  * fixed feature to disable engine
  * fixed flac preset in the converter plugin
  * fixed xfce support
  * improved Windows support:
    + added support for progress indicator in the taskbar
    (taskbar plugin)
    + added removable device detecion (rdetect plugin)
    + added exclusive mode in the WASAPI plugin
  * hid private symbols in the liqmmp and libqmmpui libraries
  * changed plugin installation path
  * resolved conflict between Qt4- and Qt5-based versions
  * using GNUInstallDirs module for cmake build
  * removed mpris1 support
  * removed support for old versions of the following libraries:
    musepack, curl, alsa, sndlib, ffmpeg
  * removed Windows XP support
  * removed uninstall plugin
  * replaced deprecated Qt classes: QDesktopWidget, QSignalMapper
  * updated Russian translation (Alexey Loginov, Viktor Eruhin)
  * updated Polish translation (mrerexx)
  * updated Portuguese translation (Sérgio Marques)
  * updated Ukrainian translation (Gennady Motsyo)
  * updated Spanish translation (Joel Barrios)
  * updated German translation (Ettore Atalan)
  * updated Greek translation (Dimitrios Glentadakis)
  * updated Galician translation (Delio Docampo Cordeiro)
  * updated Indonesian translation (Wantoyo)
  * updated Italian translation (Luigi Toscano)
  * updated Finnish translation (Jiri Grönroos)
  * updated Chinese Traditional translation (Cosmos Chen)
  version 1.2.6
  * fixed OSS4 plugin build
  * fixed 12, 20-bit integer and 32-bit float formats support in
    the WavPack plugin
* Fri Dec 21 2018 aloisio@gmx.com
- Update to version 1.2.5
  * added icon for 'exit' action in the tray icon menu
  * fixed drag-and-drop issue under Qt 5.12
  * fixed issue with 8-bit audio in the ffmpeg plugin
  * fixed latest mplayer output parsing
  * fixed '--quit' command line option processing
  * fixed issue with empty audio parameters
* Sun Nov 11 2018 olaf@aepfle.de
- ExclusiveArch x86 because ARM lacks projectM-Qt5
* Sat Sep 22 2018 sor.alexei@meowr.ru
- Update to version 1.2.4:
  * Add equaliser optimisation.
  * Update translation list.
  * Improve PCM WAVE support.
  * Fix a segmentation fault.
  * Fix tag reading in the archive plugin.
  * Fix seeking in the archive plugin.
  * Fix issue with multiscreen configuration.
  * Update translations.
* Sat Jul 21 2018 sor.alexei@meowr.ru
- Update to version 1.2.3:
  * Add Qmmp 0.12/1.3 config compatibility.
  * Disable global shortcuts during configuration.
  * Improve global hotkey plugin.
  * Fix some gcc warnings.
  * Fix metadata updating issue.
  * Fix an issue caused by sending same metadata several times in a
    row.
* Fri Jun  1 2018 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Fix building with Qt 5.11+.
  * Fix memory leaks.
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Add ffmpeg 4.0 support.
  * Add a feature to change the default user interface.
  * Fix playlists moving.
  * Fix openbox support.
  * Fix kwin support.
  * Fix mp3 detection.
  * Fix seeking by mouse wheel.
  * Fix build with Qt 5.11.
  * Update translations.
* Sun Nov 26 2017 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Add an archive reader plugin (requires TagLib 1.11 or higher).
  * Add a file writer plugin.
  * Add an icecast output plugin.
  * Add a feature to disable notifications when another application
    is in the full screen mode.
  * Add a cover tab to the track details dialogue.
  * Add a "--volume-status" command-line option.
  * Add a "--mute-status" command-line option.
  * Add a feature to change user interface from the command line.
  * Add the parent directory name to the title formatting fields.
  * Add cache to the lyrics plugin.
  * Add a feature to clear the window title when playback is
    finished.
  * Add a "Raise" method implementation to the mpris plugin.
  * Add a mount point list to the file dialogue.
  * Improve plugin API.
  * Improve cover cache.
  * Improve visualisation support.
  * Improve the aac plugin.
  * Improve audio format determination in the ffmpeg plugin.
  * Improve m3u, pls and xspf support.
  * Improve DirectSound and WASAPI support.
  * Improve the sndfile plugin.
  * Improve the mpeg plugin:
  - add lame header support;
  - add gapless support;
  - improve file type determination.
  * Improve the qsui plugin:
  - add quick search to the file system browser;
  - add quick search to the playlist;
  - add a feature to change toolbar icon size;
  - add record button;
  - add cover image alignment;
  - reduce memory usage;
  - improve settings.
  * Fix memory leaks
  * Add a Finnish translation.
  * Update Brazilian Portuguese, Czech translation,
    Chinese Simplified, French, Galician, German, Greek,
    Indonesian, Polish, Portuguese, Russian, Spanish, Japanese,
    Ukrainian translations.
- Drop qmmp-taglib-1.9.patch.
* Sun Oct 22 2017 sor.alexei@meowr.ru
- Update to version 1.1.12:
  * Fix an IPC regression.
* Fri Oct 20 2017 sor.alexei@meowr.ru
- Update to version 1.1.11:
  * Add AAC mime types to the qmmp.desktop.
  * Add album artist support in the cue parsers.
  * Using game name as album tag in the gme plugin.
  * Fix seeking in the mpris plugin.
  * Fix an issue with untracked property in the mpris plugin.
  * Fix a possible segmentation fault.
  * Fix cmake warnings.
  * Fix cmake 3.10 support.
  * Fix file size calculation in the ffmpeg plugin.
  * Fix a possible segmentation fault in the ffmpeg plugin.
  * Fix saving of the equaliser "auto" mode option.
  * Fix control socket permissions.
  * Fix rusxmms support.
  * Update Spanish, Portuguese, Greek translations.
- Rebase qmmp-projectM-qt5.patch.
* Fri Aug 25 2017 olaf@aepfle.de
- Enable mad unconditionally
* Thu Aug 10 2017 aloisio@gmx.com
- Added qmmp-projectM-qt5.patch to use projectM-qt5
* Fri Aug  4 2017 sor.alexei@meowr.ru
- Update to version 1.1.10:
  * Add a feature to download playlists from https.
  * Increase DirectSound buffer size.
  * Decrease waiting time in the WASAPI plugin.
  * Improve plugin list in the settings dialogue.
  * Fix a regression in the "jump to track" dialogue.
  * Fix a possible segmentation fault.
  * Fix seeking in the ffmpeg plugin.
  * Fix null pointer dereference in the mpeg plugin.
  * Fix gcc warnings.
  * Fix dithering settings.
  * Fix 24 bits support in the WASAPI plugin.
  * Fix segmentation fault on Ogg FLAC streams.
  * Fix XPM skins support.
  * Fix Qt 5.9 support in the global hotkey plugin.
  * Update documentation.
  * Update Galician translation.
* Tue Jun 27 2017 olaf@aepfle.de
- build conditional for mad
* Sat Jun  3 2017 sor.alexei@meowr.ru
- Update to version 1.1.9:
  * Use relative skin path for configuration portability.
  * Improve WASAPI support.
  * Fix cursors support in the skinned user interface.
  * Fix freezing when using DirectSound output.
  * Fix an issue with the "jump to track" dialogue when single
    click activation is enabled.
  * Fix tray icon tooltip.
  * Fix FLAC bitrate calculation.
  * Fix segmentation fault in the ffmpeg plugin.
  * Fix documentation.
  * Update French and Russian translations.
- Enable building with libmad for newer openSUSE releases even
  outside of Packman.
- Add qmmp-fix-openmpt.patch: fix OpenMPT compatibility.
* Thu Mar 23 2017 sor.alexei@meowr.ru
- Update to version 1.1.8:
  * Fix PCM Wave support.
  * Fix Game Boy support in the gme plugin.
  * Fix Xing header detection in the mpeg plugin.
  * Fix output of the '--status' command line option.
  * Fix maximum year in the tag editor.
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.1.7:
  * Improve stream format determination in the ffmpeg plugin.
  * Fix GCC 6.x support.
  * Fix a possible segmentation fault.
  * Fix a crash when using KDE file dialogue.
  * Fix saving state of the visual plugins.
  * Update Brazilian Portuguese translation.
* Thu Jan 12 2017 sor.alexei@meowr.ru
- Update to version 1.1.6:
  * Use the HTTP header 'icy-name' as a fallback title.
  * Enable AAC by default in the ffmpeg plugin.
  * Fix the ADTS parser in the AAC plugin.
  * Fix a possible segmentation fault.
  * Fix Ogg Opus streams support.
  * Update the Chinese Simplified translation.
* Wed Nov  9 2016 sor.alexei@meowr.ru
- Update to version 1.1.5:
  * Add FFmpeg 3.2 support.
  * Fix file downloading issue in the http plugin.
  * Fix directory selection in the qsui plugin.
  * Fix a possible segmentation fault.
  * Fix command line option '--pl-repeat-toggle'.
  * Fix some cppcheck warnings.
  * Change a file dialogue form.
* Wed Oct  5 2016 sor.alexei@meowr.ru
- Update to version 1.1.4:
  * Fix support of skins UTF-16 with encoded pledit.txt.
  * Fix 'index out of range' warning.
  * Fix typo in the qsui plugin.
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * Add a xesam:contentCreated field in the mpris plugin.
  * Improve ape/tta detection.
  * Fix random stop bug.
  * Fix duration calculation in the mpeg plugin.
  * Fix scrobbling of tracks with '&' symbol.
  * Fix ADTS parser in the aac plugin.
  * Fix librcc database path in the portable mode.
  * Update Brazilian Portuguese and German translations.
* Thu Aug  4 2016 olaf@aepfle.de
- Use buildconditional for faad and mad support
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 1.1.2:
  * Fix path to equaliser presets file in the qsui plugin.
  * Fix buffer overflow.
* Mon Jul  4 2016 sor.alexei@meowr.ru
- Update to version 1.1.1:
  * Add FFmpeg 3.1 support.
  * Fix Qt 5.7 support.
  * Fix Russian translation.
  * Update Ukrainian, Portuguese translation.
- Rebase qmmp-taglib-1.9.patch.
* Wed Jun 29 2016 sor.alexei@meowr.ru
- Add qmmp-taglib-1.9.patch: extend TagLib support to 1.9.
* Tue Jun 21 2016 sor.alexei@meowr.ru
- Update to version 1.1.0:
  * Use floating point pcm format for all lossy decoders.
  * Use floating point pcm format for all audio effects.
  * Add new internal audio converter.
  * Add dithering setting.
  * Add feature to change output bit depth.
  * Add feature to change volume adjustment step.
  * Add soxr-based resampler plugin.
  * Remove libsamplerate-based resampler.
  * Add Qt Multimedia output plugin.
  * Add feature to refresh playlist.
  * Add two-panel file dialog.
  * Add feature to scrobble http streams.
  * Add multi-thread support in the audio converter plugin.
  * Add support for m4a files in the ReplayGain scanner.
  * Add WASAPI output plugin.
  * Add https support in the http plugin.
  * Add wildmidi 0.4.0 support.
  * Add support for XMIDI and MUS (id Software) formats.
  * Improve skinned interface:
  - show track details when double-clicking on song title in the
    main window;
  - improve time indicator in the shaded mode;
  - add feature to disable anti-aliasing;
  - add feature to seek by mouse wheel;
  - add column alignment option.
  * Improve simple user interface (qsui):
  - add column alignment option;
  - add feature to add/remove sliders;
  - add feature to create multiple panels;
  - add tooltips for the sliders;
  - improve volume slider;
  - fix problem with minimum width.
  * Improve wavpack plugin:
  - add some optimisations;
  - fix a memory leak.
  * Improve ffmpeg plugin:
  - add support for m4a embedded album art;
  - add replaygain support
  * Improve ladspa plugin.
  * Improve command line parser.
  * Improve details dialog.
  * Improve "jump to track" dialog.
  * Change default settings in the mpeg plugin.
  * Fix metadata encoding issue in the http plugin.
  * Fix compiz support.
  * Fix disc number parsing.
  * Update Bulgarian translation, Chinese Traditional,
    Chinese Simplified, French, German, Greek, Hebrew, Japanese,
    Portuguese, Russian, Ukrainian translations.
- Rebase qmmp-default-pulse.patch.
* Tue May 31 2016 sor.alexei@meowr.ru
- Update to version 1.0.10:
  * Improve sid plugin:
    + add c64 file extension;
    + fix default HVSC path.
  * Update Japanese translation.
* Tue May  3 2016 sor.alexei@meowr.ru
- Update to version 1.0.9 (changes since 1.0.7):
  * Fix session check in the scrobbler plugin.
  * Fix working with both libre.fm and last.fm.
  * Fix cell height in the stream browser.
  * Remove borders from statusbar in the qsui plugin.
  * Fix taglib-1.9 support.
* Sun Apr  3 2016 sor.alexei@meowr.ru
- Update to 1.0.7:
  * Add ffmpeg 3.0 support.
  * Add support for theme change event in the qsui plugin.
  * Fix sending multiple play commands when opening several files
    for playback.
  * Fix memory leaks.
  * Fix Qt 5.6 support.
* Sat Jan 30 2016 rpm@fthiessen.de
- Fixed build by rebasing qmmp-default-pulse.patch
  to work with 1.0.6
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to 1.0.6:
  * Add a feature to change default output plugin.
  * Add a feature to skip unsupported files in the rgscan plugin.
  * Fix gme plugin building.
  * Fix GCC warnings.
  * Fix Russian translation.
  * Update Portuguese, Chinese Simplified translations
* Sat Jan  2 2016 sor.alexei@meowr.ru
- Update to 1.0.5:
  * Add GNOME Shell support.
  * Fix url dialog size.
  * Fix memory leak in the qsui plugin.
  * Fix LADSPA plugin.
  * Fix CPU usage in the vorbis plugins.
  * Fix UTF-8 support in the scrobbler plugin.
  * Fix Greek translation.
  * Update French translation.
* Mon Dec 21 2015 sor.alexei@meowr.ru
- Update to 1.0.4:
  * Fix skinned ui build.
* Thu Dec 17 2015 sor.alexei@meowr.ru
- Update to 1.0.3:
  * Add error handling in the MPlayer plugin.
  * Fix problem with some covers embedded in the mp3 files.
  * Fix some skins support.
  * Fix issue with equaliser not saving low levels in the qsui
    plugin.
  * Fix gcc warnings.
  * Fix build without Qt X11 Extras.
  * Fix Cinnamon and MATE support.
  * Update Chinese Simplified translation.
* Sun Nov 15 2015 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Fix problem with tray icon menu (see qtbug#48869).
  * Fix geometry saving in the skinned UI.
  * Fix segmentation fault in the ReplayGain scanner.
  * Fix hide on close feature.
  * Fix some skins parsing.
  * Fix Dutch translation.
* Wed Nov  4 2015 sor.alexei@meowr.ru
- Update to 1.0.1 (changes since 0.9.3):
  * Switch to Qt5.
  * Add Xfce icon theme support.
  * Add test for supported OpenGL implementation while using cmake.
  * Remove ffmpeg_legacy plugin.
  * Remove legacy udisks plugin.
  * Remove support of taglib versions less than 1.8.
- Switch to Qt5.
* Thu Oct 22 2015 sor.alexei@meowr.ru
- Update to 0.9.3:
  * Improve command line parser.
  * Fix crash in the mplayer engine.
  * Fix time indicator in the qsui plugin.
  * Fix truncated output of the '--pl-dump' command.
  * Fix track indexes calculation.
* Fri Oct  2 2015 sor.alexei@meowr.ru
- Update to 0.9.2:
  * Optimise equaliser.
  * Optimise FLAC and WavPack plugins.
  * Improve skinned UI in the shaded mode:
  - improved time indicator;
  - fixed playlist colours.
  * Fix clicks while playing some MP3 files.
  * Fix memory leak in the WavPack plugin.
  * Fix Qt 4.6 support.
  * Fix ffmpeg 0.5 support.
  * Fix effects and decoders sorting.
  * Fix possible race condition.
  * Update Greek translation.
- Rename libqmmp1-plugins to libqmmp-plugins: can't be
  multiversioned.
- Only install libqmmp-plugin-mplayer in PMBS.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.9.1:
  * Fix 16-bit converter.
  * Improve Russian translation.
- Rename & rebase qmmp-0.6.1-default_pulse.patch to
  qmmp-default-pulse.patch.
- Build with ffmpeg support outside PMBS as well.
- Do not force UNIX permissions in %%files globally.
- Obsolete qmmp-plugin-pack-simple-ui as it's merged with
  libqmmp0-plugins.
* Sat Sep  5 2015 quarckster@gmail.com
- Update to 0.9.0:
  * added "Save List" action to the tab menu;
  * added *.med files support;
  * added 9 channels support to equalizer;
  * added album artist tag support;
  * added asynchronous sorting;
  * added audio-channel sequence converter;
  * added default hotkey for the "Rename List" action;
  * added feature to change user agent;
  * added feature to change window title;
  * added feature to disable fadeout in the gme plugin;
  * added feature to disable plugins without qmmp.pri modification (qmake only)
  * added feature to exclude cue data files;
  * added feature to hide song length;
  * added feature to hide track length;
  * added feature to move files;
  * added feature to remember playlist scroll position;
  * added feature to reset fonts;
  * added feature to reset shortcuts;
  * added feature to restore default shortcuts;
  * added multiple column support;
  * added s3m, stm and xm extensions to desktop files;
  * added Simple User Interface (QSUI) with the following changes:
  * added sorting by album artist;
  * added sorting by file modification date;
  * changed default playlist separator;
  * changed default skin to Glare;
  * fixed cmake support;
  * fixed config directory path;
  * fixed crash when quitting while playlist is being populated;
  * fixed details dialog form;
  * fixed documentation;
  * fixed home page;
  * fixed main window activation;
  * fixed minimizing throw taskbar under windows;
  * fixed opus plugin;
  * fixed some skins parsing;
  * fixed some skins support;
  * fixed support of keyboards with single play/pause button;
  * fixed text scroller colors;
  * fixed typos;
  * improved ape tags support in the mpeg plugin;
  * improved cmake build scripts;
  * improved fileops plugin:
  * improved global hotkey settings;
  * improved playlist changes notification;
  * improved status bar;
  * improved title formatter;
  * increased details dialog size;
  * optimized playlist container;
  * optimized sample rate converter;
  * reduced cpu usage;
  * reworked settings dialog;
  * updated Czech translation;
  * updated French translation;
  * updated German translation;
  * updated Greek translation;
  * updated Hebrew translation;
  * updated Japanese translation;
  * updated Japanese translation;
  * updated Polish translation;
  * updated Portuguese translation;
  * updated Russian translation;
  * updated Ukrainian translation;
  * using DirectSound output as default under Windows.
* Tue Jun  9 2015 quarckster@gmail.com
- Update to 0.8.5
  * added icons for some actions;
  * fixed multiple connections to same signal when switching playlists;
  * fixed api documentation;
  * fixed playlist selector drawing bug;
  * fixed Portuguese translation;
  * fixed Hebrew translation;
  * updated Turkish translation;
  * added user data directory support;
  * increased player thread priority under windows;
  * fixed playlist resizing on RTL locales;
  * fixed vorbis comment support;
  * fixed build using qmake;
  * fixed cover disappearing bug;
  * fixed windows executable file description;
  * fixed settings form;
  * fixed problem with path separators under windows;
  * fixed libre.fm support;
  * fixed some skin parsing;
  * fixed support of some skins;
  * fixed modplug plugin settings.
* Tue Jan  6 2015 quarckster@gmail.com
- Update to 0.8.3
  * reduced time of the 'Randomize List' and "Remove Duplicates" operations;
  * fixed ffmpeg 2.5 support;
  * fixed 24/32 bit modes in the equalizer;
  * fixed skin parsing;
  * fixed autoplay when playlist was opened from command line;
  * updated Portuguese translation;
  * updated Czech translation.
* Tue Oct 21 2014 quarckster@gmail.com
- Update to 0.8.2
  * added transifex integration;
  * added webm support;
  * improved image scaling quality;
  * fixed xspf parsing;
  * fixed cover loading sequence;
  * fixed main window activation under windows;
  * fixed analyzer color settings;
  * fixed typos;
  * fixed possible segmentation fault in the opus;
  * fixed separator of the file filters;
  * reduced tag reading delay (requires TagLib 1.8 or higher);
  * updated Russian translation;
  * updated Ukrainian translation;
  * updated Japanese translation.
  * added rusxmms patch autodetection to the mpg123 plugin;
  * fixed selection behaviour when using keyboard in the qsui plugin;
  * fixed main window activation in the qsui plugin.
* Fri Jul 11 2014 reddwarf@opensuse.org
- Update to 0.8.0
  * added sid plugin
  * added ReplayGain scanner
  * added gnome hotkey plugin
  * added DirectSound plugin
  * added track grouping view
  * added sorting by group
  * added quick search to the playlist browser
  * added multiple tracks support to the details dialog
  * added context menu to the plugin settings page
  * added lazy plugin loading
  * added feature to disable transport plugins
  * added data waiting condition for transport plugins
  * added floating point output for lossy decoders
  * added peak overflow support for lossy decoders
  * added support for id3v2-based ReplayGain tags
  * added clipping prevention using ReplayGain information
  * added delayed initialization in the wildmidi plugin
  * added volume control hotkeys
  * added 'mute' global hotkey
  * added '--toggle-mute' command line option
  * added '--show-mw' command line option
  * added ogg opus preset to the converter plugin
  * added scrobbler 2.0 api for libre.fm
  * added context menu in the window of the analyzer plugin
  * added window flags access from visual plugin api
  * added atomic playlist saving operation
  * added created playlist auto-selection
  * added feature to not clear previous playlist when opening new one
  * added mplayer command line options setting
  * added Serbian translation (Mladen Pejaković)
  * blocked one hotkey assignment for several commands in the hotkey plugin
  * limited cover cache size
  * improved 'jump to track' dialog
  * improved projectm plugin:
  - added context menu
  - added multi-channel mode
  - added list of presets
  - added win32 support
  * improved win32 support
  - enabled support for the enca library
  - added feature to add files from multiple instances
  - added file associations support (based on SMPlayer implementation)
  - added uninstall support
  * fixed noise on buffer underrun
  * fixed title format in the shaded mode
  * fixed alt-f4 behavior
  * fixed possible race condition
  * fixed possible segmentation fault in the mad plugin
  * fixed 'eject' button function
  * fixed raise of the main window when starting another instance
  * fixed default skin
  * updated Russian translation
  * updated Hebrew translation (Genghis Khan)
  * updated Ukrainian translation (Gennadi Motsyo)
  * updated Serbian translation (Mladen Pejaković)
  * updated Polish translation (Grzegorz Gibas)
  * updated Lithuanian translation (Algirdas Butkus)
- Add pkgconfig(libsidplayfp) build dependency
* Fri Jun  6 2014 reddwarf@opensuse.org
- Update to 0.7.7
  * fixed typos
  * fixed Polish locale support
  * removed 'OnlyShowIn' key from qmmp.desktop
  * removed useless files
* Wed Apr 16 2014 reddwarf@opensuse.org
- Update to 0.7.6
  * added libav 10 and ffmpeg 2.2 support
  * fixed url parsing
  * fixed freezing on playback resume
  * fixed random freezing in the mplayer plugin
  * fixed reset selection of tracks when calling context menu
  * fixed multimedia keys support under win32
* Thu Feb 13 2014 reddwarf@opensuse.org
- Update to 0.7.5
  * fixed case sensitivity while checking file extensions (tnanks to Ryota Shimamoto)
  * fixed special global keys support under the win32 platform
  * fixed latest cmake support
  * fixed initial position of the equalizer volume slider
  * fixed clang warnings
- Update to 0.7.4
  * added Galician translation (Óscar Pereira)
  * added ffmpeg 2.1 support
  * added m3u8 playlist extension
  * improved ReplayGain support:
  - fixed 24/32 bit mode
  - added clipping to prevent overflow
  * improved cdaudio plugin:
  - added Windows support
  - added track cache
  - fixed proxy support
  * fixed localization of the wildmidi plugin
  * fixed case sensitivity while checking file extensions
  * fixed gcc 4.8 warnings
  * fixed memory leak
  * fixed several Windows-only bugs:
  - fixed parsing of the m3u files with backslashes
  - fixed problem with absolute paths
  - fixed adding files from command line under Windows
  - fixed Meta/Win modifier in the global hotkey plugin
  * fixed Japanese translation (RyōTa SimaMoto)
* Thu Oct  3 2013 reddwarf@opensuse.org
- Update to 0.7.3
  * added window size and position saving to the projectm plugin
  * disabled unsupported settings in the statusicon plugin under Windows
  * fixed warnings about invalid parent thread
  * fixed race condition
  * fixed ReplayGain support in the flac plugin
  * fixed parsing of the track/disc number with separator
  * fixed tooltip in the status icon plugin under Windows
  * fixed 'show tooltip' option in the status icon plugin
  * removed unused variables
* Wed Aug 28 2013 reddwarf@opensuse.org
- Update to 0.7.2
  * fixed queue update bug
  * fixed track length formatting
  * fixed api documentation
  * fixed gcc warnings
  * fixed memory leaks
  * fixed wildmidi config path
  * fixed playlist autosave feature
  * fixed possible segmentation fault
  * fixed title format update bug
  * removed unimplemented function
* Fri May 31 2013 reddwarf@opensuse.org
- Update to 0.7.1
  * improved jack plugin (24/32-bit samples and freebsd support)
  * excluded mime types of disabled plugins in the mpris interface
  * fixed windows support in the gme plugin
  * fixed shortcut editor dialog
  * fixed api documentation
  * fixed parsing of the icy packet size
  * fixed possible freezes
  * fixed Spanish translation (thanks to Gustavo Alvarez)
  * fixed and improved qmake support (Ryota Shimamoto)
  * fixed pkg-config support
  * fixed several ui bugs
  * fixed scrobbler regressions
* Wed May 15 2013 mhrusecky@suse.com
- Only suggesting instead of recomending mplayer plugin as mplayer is not in
  factory yet
* Mon Apr 15 2013 pascal.bleser@opensuse.org
- update to 0.7.0:
  * added udisks2 plugin
  * added opus plugin
  * added track change plugin
  * added tracks copy/paste plugin
  * added x-content/audio-cdda content type
  * added 24/32-bit equalizer
  * added unity integration
  * added user interface language option
  * added playlists auto-save feature
  * added unified URL dialog
  * added playlists downloading support to the command line parser
  * added volume control support to the waveout plugin
  * added wildmidi configuration file auto-search
  * added sorting by file creation date
  * added automatic 16-bit audio converter
  * added pause handling to the scrobbler plugin
  * enabled UTF-8 by default for cue files and shoutcast metadata
  * enabled more formats by default in the ffmpeg plugin
  * improved analyzer plugin (variable size, fullscreen mode, etc)
  * improved last.fm registration
  * improved configuration dialog
  * removed QtXML dependence from the scrobbler plugin
  * disabled udisks plugin by default
* Thu Mar 28 2013 reddwarf@opensuse.org
- Update to 0.6.8
  * fixed bugs in the mpris plugin
  * fixed segmentation fault when running without output plugins
  * updated Japanese translation (Ryota Shimamo)
* Thu Feb 21 2013 reddwarf@opensuse.org
- Update to 0.6.7
  * added lubuntu integration
  * improved rtl locales support
  * fixed latest paranoia support
  * fixed libav 0.8.x support
  * fixed 'enter' hotkey in the playlist browser
  * fixed 24-bit mode support in the src plugin
  * fixed compiler warnings
* Fri Jan 11 2013 reddwarf@opensuse.org
- Update to 0.6.6
  * added support for http redirect to the url dialog
  * added ffmpeg 1.1 support
  * fixed 24/32-bit mode support in the src plugin
  * fixed seeking when using oss4 as output
  * fixed streaming support in the ffmpeg plugin
  * fixed build without qt3support headers (thanks to Dmitry Smolin)
  * fixed playlist titlebar cursor
  * fixed mpris2 support
  * fixed typos
  * updated Hebrew translation (Genghis Khan)
- Disable OSS/OSS4 output support
* Sun Dec  9 2012 reddwarf@opensuse.org
- Update to 0.6.5
  * added latest psi/psi+ support
  * added Hebrew translation (Genghis Khan)
  * increased default mms/http buffer size
  * fixed shortcut dialogs
  * fixed segmentation fault caused by http transport
  * fixed file type determination by content
  * fixed division line position in the playlist
  * fixed some bugs in the WaveOut plugin
  * updated Japanese translation (Ryota Shimamoto)
  * updated Russian translation
  * updated flac mime-type (Christian Morales Vega)
- Drop qmmp-0.6.4-flac_mimetype.patch. Applied upstream.
* Thu Dec  6 2012 reddwarf@opensuse.org
- Add qmmp-0.6.4-flac_mimetype.patch to use the correct MIME type
  to report support for FLAC files
* Sun Nov  4 2012 reddwarf@opensuse.org
- Update to 0.6.4
  * using UTF-8 encoding for shoutcast metadata by default
  * fixed visualization menu update after changing settings
  * fixed skinned user interface settings
  * fixed analyzer falloff speeds
  * fixed skinned user interface visualization switching
  * fixed playlist titlebar resize bug
  * fixed color selection widget
  * fixed possible crash in the transport plugins
  * fixed Russian translation
  * updated Japanese translation (Ryota Shimamoto)
* Wed Aug 22 2012 reddwarf@opensuse.org
- Update to 0.6.3
  * fixed typo in the about dialog
  * fixed FSF address
  * fixed cmake scripts
  * fixed filters of the directory scanner
  * fixed crash in the playlist popup message
  * updated Lithuanian translation (Algirdas Butkus)
- Removed qmmp-0.5.5-libcdio_mess.patch, fixed upstream
* Sat Aug  4 2012 reddwarf@opensuse.org
- Make qmmp require at least an input, output and ui plugin
* Mon Jul 30 2012 reddwarf@opensuse.org
- Update to 0.6.2
  * fixed crash in the http plugin
  * fixed possible crash in the cue parser
* Mon Jul 23 2012 reddwarf@opensuse.org
- Update to 0.6.1
  * added icons to the file dialog buttons
  * fixed icecast streams titles
  * fixed build
  * fixed default output under windows
  * fixed api documentation
  * fixed possible segmentation fault in the cue plugin
  * fixed cue parsing
  * fixed automatic charset detection
  * fixed Ukrainian translation (Gennadi Motsyo)
  * fixed Russian translation
* Sat Jun 30 2012 reddwarf@opensuse.org
- Update to 0.6.0
  * added converter plugin
  * added stream browser plugin
  * added file type determination by content (experimental)
  * added '--quit' command line option
  * added text scroller background option
  * added playlists separator option
  * added multiband equalizer api
  * added equalizer presets from Amarok (Thanks to Panagiotis Papadopoulos)
  * added playlits access from command line
  * added dithering to MPEG plugin
  * added priority support to decoder api
  * added user interface api
  * added default destination and file name pattern to fileops plugin
  * added additional directory filters
  * added feature to add files from command line to specific playlist
  * added pkg-config support
  * added vqf support
  * added feature to display shoutcast stream information
  * added 'jump to track' and 'forward/rewind' global hotkeys
  * added 'New Playlist' button
  * added sorting by disc number (Brice Videau)
  * added feature to use clipboard content in the URL dialog (Panagiotis Papadopoulos)
  * added scrobbler cache synchronization after successful submission (Ferdinand Vesely)
  * changed playlist insertion behavior
  * disabled OSS3 plugin by default
  * improved cue plugin
  * moved skinned ui to separate plugin
  * fixed 'hide on close' feature
  * fixed moc warnings during compilation
  * fixed IPC under windows
  * fixed windows-specific bugs
  * fixed problems with some asynchronous calls
  * fixed qmmp_cue.desktop
  * fixed saving playlists on logout
  * updated about dialog
  * updated Russian translation
  * updated Ukrainian translation (Gennadi Motsyo)
  * updated Japanese translation (Ryota Shimamoto)
  * updated Polish translation (Grzegorz Gibas)
  * updated German translation (Panagiotis Papadopoulos)
  * updated Dutch translation (Ronald Uitermark)
* Thu May 31 2012 reddwarf@opensuse.org
- Disable HAL plugin build
- Disable OSS plugin build
- Use PulseAudio by default instead of ALSA
* Sun May 27 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Sat May 26 2012 reddwarf@opensuse.org
- Update to 0.5.5
  * added latest libcdio support
  * fixed Russian translation
  * fixed acc streams support
  * fixed aac bitrate calculation
  * fixed scrobbler failure when using Qt 4.8
  * fixed some cuesheets parsing
  * fixed --pause command line option behavior
  * updated Japanese translation
- Add missing %%desktop_database_post and %%icon_theme_cache_post
  scripts
- Remove obsoleted %%suse_update_desktop_file calls
- Add qmmp-0.5.5-libcdio_mess.patch to fix build with git version
  of libcdio
* Mon Sep  6 2010 reddwarf@opensuse.org
- New package. Version 0.4.2
